@@ -34,11 +34,14 @@ def main(mode='render'):
         
     return n
 
-if __name__ == "__main__":
+def run():
     kwargs = {}
 
     if len(sys.argv) > 1:
         if sys.argv[1] == 'serve':
             kwargs.update(mode='serve')
 
-    o = main(**kwargs)
+    return main(**kwargs)
+
+if __name__ == "__main__":
+    run()
\ No newline at end of file
